@@ -1,7 +1,7 @@
 from dotenv import find_dotenv, load_dotenv
 from llama_index.core import SimpleDirectoryReader, VectorStoreIndex
 
-from instrumentation.setup import setup_instrumentation
+from examples.setup import setup_instrumentation
 from instrumentation.with_root_span import with_langtrace_root_span
 
 _ = load_dotenv(find_dotenv())
